@@ -309,7 +309,7 @@ psscan(FILE * file, int respect_eof, const gchar * fname)
     gchar *test_cmd;
 
     test_cmd = g_strdup_printf
-      ("%s -dNOPAUSE -dBATCH -sDEVICE=nullpage %s "
+      ("%s -dSAFER -dNOPAUSE -dBATCH -sDEVICE=nullpage %s "
        "1>/dev/null 2>/dev/null", gtk_gs_defaults_get_interpreter_cmd(), fname);
     if(system(test_cmd) != 0) {
       g_free(test_cmd);
@@ -609,7 +609,7 @@ psscan(FILE * file, int respect_eof, const gchar * fname)
       if(!DSCcomment(line)) {
         /* Do nothing */
       }
-      else if(doc->default_page_orientation == NONE &&
+      else if(doc->default_page_orientation == GTK_GS_ORIENTATION_NONE &&
               iscomment(line + 2, "PageOrientation:")) {
         sscanf(line + length("%%PageOrientation:"), "%256s", text);
         if(strcmp(text, "Portrait") == 0) {
@@ -737,7 +737,7 @@ psscan(FILE * file, int respect_eof, const gchar * fname)
       if(!DSCcomment(line)) {
         /* Do nothing */
       }
-      else if(doc->default_page_orientation == NONE &&
+      else if(doc->default_page_orientation == GTK_GS_ORIENTATION_NONE &&
               iscomment(line + 2, "PageOrientation:")) {
         sscanf(line + length("%%PageOrientation:"), "%256s", text);
         if(strcmp(text, "Portrait") == 0) {
@@ -882,7 +882,7 @@ newpage:
       if(!DSCcomment(line)) {
         /* Do nothing */
       }
-      else if(doc->pages[doc->numpages].orientation == NONE &&
+      else if(doc->pages[doc->numpages].orientation == GTK_GS_ORIENTATION_NONE &&
               iscomment(line + 2, "PageOrientation:")) {
         sscanf(line + length("%%PageOrientation:"), "%256s", text);
         if(strcmp(text, "Portrait") == 0) {
